### 0.12.2 {small}`2025-04-11`

```{rubric} Features
```
* Adds `gr.co_occurrence` {pr}`342` {smaller}`S Dicks`

```{rubric} Misc
```
* rsc is now tested with `RAPIDS-25.04` {pr}`349` {smaller}`S Dicks`
* rapids-singlecell now installs with `RAPIDS-25.04` {pr}`349` {smaller}`S Dicks`
* Updates the docker for `RAPIDS-25.04` {pr}`349` {smaller}`S Dicks`
